@@ -1,8 +1,8 @@
 # -*- shell-script -*-
 # gdb-like "frame" debugger command
 #
-#   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008, 2010 Rocky Bernstein
-#   <rocky@gnu.org>
+#   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008, 2010, 2011 
+#   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -13,7 +13,7 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
@@ -29,12 +29,27 @@ most-recent frame, 0, if no frame number specified.
 
 A negative number indicates the position from the other or 
 least-recently-entered end.  So "frame -1" moves to the oldest frame.
-'
+' 1 _Dbg_complete_frame
 
+# Command completion for a frame command
+_Dbg_complete_frame() {
+    typeset -i start; ((start=-_Dbg_stack_size+1))
+    typeset -i end;   ((end=_Dbg_stack_size-1))
+    _Dbg_complete_num_range $start $end
+}
+
 _Dbg_do_frame() {
-  _Dbg_not_running && return 3
-  typeset -i pos=${1:-0}
-  _Dbg_frame_adjust $pos 0
-  return $?
+    _Dbg_not_running && return 3
+    typeset count=${1:-1}
+    _Dbg_is_signed_int $count 
+    if (( 0 == $? )) ; then
+	_Dbg_frame_adjust $count 0
+	typeset -i rc=$?
+    else
+	_Dbg_errmsg "Expecting an integer; got $count"
+	typeset -i rc=2
+    fi
+    ((0 == rc)) && _Dbg_last_cmd='frame'
+    return $rc
 }
 
