@@ -1,7 +1,7 @@
 # -*- shell-script -*-
-# gdb-like "next" (step over) commmand.
+# gdb-like "next" (step through) commmand.
 #
-#   Copyright (C) 2010 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2008, 2010 Rocky Bernstein rocky@gnu.org
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -12,7 +12,7 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
@@ -23,7 +23,9 @@
 # but the command is different.
 
 _Dbg_help_add next \
-"next [COUNT]	-- Single step an statement skipping functions.
+"next [COUNT]
+
+Single step an statement skipping functions.
 
 If COUNT is given, stepping occurs that many times before
 stopping. Otherwise COUNT is one. COUNT an be an arithmetic
@@ -32,6 +34,9 @@ expression.
 Functions and source'd files are not traced. This is in contrast to 
 \"step\". See also \"skip\"."
 
+# Next command
+# $1 is command next+, next-, or next
+# $2 is an optional additional count.
 _Dbg_do_next() {
     _Dbg_last_cmd='next'
     _Dbg_inside_skip=0
