@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "set autolist" debugger command
 #
-#   Copyright (C) 2010 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2010, 2011 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -12,12 +12,19 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
+_Dbg_help_add_sub set autolist \
+'set autolist [on|off]
+
+Run a \"list\" command automatically every time the debugger enters.' 1
+
+_Dbg_next_complete[set autolist]='_Dbg_complete_onoff'
+
 _Dbg_do_set_autolist() {
     typeset onoff=${1:-'off'}
     case $onoff in 
