@@ -19,7 +19,9 @@
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 
 _Dbg_help_add tty \
-'tty -- Set the output device for debugger output.'
+'tty
+
+Set the output device for debugger output.'
 
 # Set output tty
 _Dbg_do_tty() {
