@@ -1,6 +1,5 @@
 #!/bin/bash
 # -*- shell-script -*-
-
 test_alias()
 {
     _Dbg_alias_add u up
@@ -30,17 +29,15 @@ test_alias()
     assertEquals 'up' $expanded_alias
 }
 
-# Make sure ../.. has a trailing slash
 if [ '/src/external-vcs/bashdb' = '' ] ; then
   echo "Something is wrong: abs_top_srcdir is not set."
  exit 1
 fi
 abs_top_srcdir=/src/external-vcs/bashdb
+# Make sure $abs_top_srcr has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
-
+. ${abs_top_srcdir}test/unit/helper.sh
 . $abs_top_srcdir/lib/help.sh
 . $abs_top_srcdir/lib/alias.sh
-
-# load shunit2
-shunit_file=${abs_top_srcdir}test/unit/shunit2
-. ${shunit_file}
+set -- # reset $# so shunit2 doesn't get confused.
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
