@@ -1,6 +1,5 @@
 #!/bin/bash
 # -*- shell-script -*-
-
 test_columnized()
 {
     do_one() {
@@ -44,12 +43,10 @@ if [ '/src/external-vcs/bashdb' = '' ] ; then
  exit 1
 fi
 abs_top_srcdir=/src/external-vcs/bashdb
-# Make sure @abs_top_srcr@ has a trailing slash
+# Make sure $abs_top_srcrdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
-
+. ${abs_top_srcdir}test/unit/helper.sh
 . $abs_top_srcdir/lib/columnize.sh
 
-# load shunit2
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+set -- # reset $# so shunit2 doesn't get confused.
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
