@@ -23,15 +23,17 @@ test_undefined()
     typeset _Dbg_tty=''
     typeset msg
     msg=$(_Dbg_undefined_cmd foo bar)
-    assertEquals 'Undefined foo subcommand "bar". Try "help foo".' "$msg"
+    assertEquals '** Undefined foo subcommand "bar". Try "help foo".' "$msg"
     msg=$(_Dbg_undefined_cmd foo)
-    assertEquals 'Undefined command "foo". Try "help".' "$msg"
+    assertEquals '** Undefined command "foo". Try "help".' "$msg"
 }
 
-# load shunit2
-top_srcdir=/src/external-vcs/bashdb
-. ${top_srcdir}/lib/msg.sh
-. ${top_srcdir}/dbg-io.sh
-
-. ${top_srcdir}/test/unit/shunit2
+abs_top_srcdir=/src/external-vcs/bashdb
+# Make sure $abs_top_srcdir has a trailing slash
+abs_top_srcdir=${abs_top_srcdir%%/}/
+. ${abs_top_srcdir}test/unit/helper.sh
+. ${abs_top_srcdir}/lib/msg.sh
+. ${abs_top_srcdir}/init/io.sh
+set -- # reset $# so shunit2 doesn't get confused.
 
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
